@@ -4,6 +4,7 @@ from functools import lru_cache
 from textwrap import dedent, indent
 from urllib.parse import urljoin
 
+import django.db.models.options as options
 from cached_property import cached_property
 from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
@@ -20,6 +21,9 @@ from urlid_graph.utils import random_name
 from . import formatting
 
 
+options.DEFAULT_NAMES = options.DEFAULT_NAMES + ("entity_name", "entity_uuid", "search_fields", "slug")
+
+
 REGEXP_CAMEL_CASE = re.compile("([A-Z])")
 
 
