@@ -11,7 +11,7 @@ from urlid_graph import settings as urlid_graph_settings
 from .exceptions import InvalidEdgeIdException
 from .formatting import format_property_value, format_unknown_property_value
 from .graph_db import parse_edge_id
-from .models import Object, RelationshipConfig, RelPropertyConfig, SavedGraph
+from .models import ObjectRepository, RelationshipConfig, RelPropertyConfig, SavedGraph
 
 
 def _sorted_properties(props):
@@ -89,22 +89,15 @@ class SavedGraphSerializer(serializers.ModelSerializer):
         validators = [UniqueTogetherValidator(queryset=SavedGraph.objects.all(), fields=["user", "name"])]
 
 
-class EdgeUrlsSerializerMixin(serializers.Serializer):
-    detail_url = serializers.SerializerMethodField()
-
-    def get_detail_url(self, obj):
-        return reverse("graph_api:edge_detail", args=[obj["id"]])
-
-
-class EdgeSerializer(EdgeUrlsSerializerMixin, serializers.Serializer):
+class EdgeSerializer(serializers.Serializer):
     name = serializers.CharField(source="label")
     to = serializers.CharField()
     id = serializers.CharField()
     label = serializers.SerializerMethodField()
 
     def __init__(self, *args, **kwargs):
-        # from is a reserved word and can't be used to declare fields the same way
-        # as the others are declared
+        # from is a reserved word and can't be used to declare fields the same
+        # way as the others are declared
         self.fields["from"] = serializers.CharField()
         super().__init__(*args, **kwargs)
 
@@ -131,25 +124,19 @@ class DetailedEdgeSerializer(EdgeSerializer):
         return _sorted_properties(props)
 
 
-class NodeUrlsSerializerMixin(serializers.Serializer):
-    detail_url = serializers.SerializerMethodField()
-    relationships_url = serializers.SerializerMethodField()
-
-    def get_detail_url(self, obj):
-        return reverse("graph_api:node_detail", args=[obj.uuid])
-
-    def get_relationships_url(self, obj):
-        return reverse("graph_api:node_rels", args=[obj.uuid])
-
-
-class NodeSerializer(NodeUrlsSerializerMixin, serializers.ModelSerializer):
+class NodeSerializer(serializers.ModelSerializer):
     group = serializers.CharField(source="entity.name")
     label = serializers.CharField()
     id = serializers.CharField(source="uuid")
 
     class Meta:
-        model = Object
-        fields = ["id", "group", "url", "label", "detail_url", "relationships_url"]
+        model = ObjectRepository
+        fields = ["id", "group", "label"]
+
+    def to_representation(self, instance):
+        result = super().to_representation(instance)
+        result["properties"] = instance.properties
+        return result
 
 
 class DetailedNodeSerializer(NodeSerializer):
@@ -157,7 +144,7 @@ class DetailedNodeSerializer(NodeSerializer):
 
     class Meta:
         model = NodeSerializer.Meta.model
-        fields = NodeSerializer.Meta.fields + ["properties", "detail_url", "relationships_url"]
+        fields = NodeSerializer.Meta.fields + ["properties"]
 
     def get_properties(self, obj):
         props = {}
