@@ -9,7 +9,7 @@ from rest_framework.views import APIView
 
 from .exceptions import InvalidEdgeIdException
 from .mixins import GraphDbMixin
-from .models import Entity, ObjectRepository, SavedGraph
+from .models import DatasetModel, Entity, ObjectRepository, SavedGraph
 from .serializers import (
     AllNodesRelationshipsSerializer,
     ConfigSerializer,
@@ -26,7 +26,7 @@ def get_first_object_or_404(ModelClass, **filters):
     """Get object (if multiple found, return first) or raise 404"""
     obj = ModelClass.objects.filter(**filters).first()
     if obj is None:
-        raise Http404()
+        raise Http404
     else:
         return obj
 
@@ -223,3 +223,20 @@ class ShortestPathEndpoint(GraphDbMixin, APIView):
     def get(self, request, from_uuid, to_uuid, *args, **kwargs):
         nodes, edges = self.graph.get_shortest_path(from_uuid, to_uuid)
         return Response(self.serialize_graph(nodes, edges))
+
+
+class DatasetFilter(APIView):
+
+    def get_model(self, slug):
+        dataset_models = DatasetModel.subclasses()
+        if slug not in dataset_models:
+            raise Http404
+        return dataset_models[slug]
+
+    def get(self, request, slug, object_uuid):
+        Model = self.get_model(slug)
+        objects = Model.objects.filter(object_uuid=object_uuid)
+        return Response({
+            "fields": Model.fields(),
+            "result": [obj.serialize() for obj in objects],
+        })
